//
// Copyright (c) 1997 Content Technologies Limited. All rights reserved.
//
// HEADER
//
//		simplblk.cpp
//
// PACKAGE
//
//		UBK - URL Blocker
//
// DESCRIPTION
//
//		This class is provided as an example of how to implement your own URL
//		blocker.
//
//
// REFERENCES
//
//		None.
//
// HISTORY
//
//		AUTHOR				DATE				CHANGES
//
//		Dominic Chambers	15-December-1997	Initial Version
//		Dominic Chamber		13-January-1998		Host IP address is now a parameter
//												of url block queries.
//

#include "simplblk.hpp"

static const char UBK_BLOCK_MESSAGE_ENTRY[] = "BlockMessage";
static const char UBK_REDIRECT_ENTRY[]      = "RedirectPage";
static const char UBK_BLOCK_URL_ENTRY[]     = "BlockURL";



// This function is called when the DLL is initialised. It is here that you
// must report any errors that may affect the url blockers ability to operate.
// If errors are detected you will need to ensure that the user can find out
// what the problem was. The Event Log is an ideal candidate for this.
BOOL Simple_block::initialise()
{
	// This sample url blocker checks the configuration file for two entries (BlockURL
	// and either BlockMessage or RedirectPage), which it expects in that order. The first
	// entry defines the url to block, and the second defines the message to return  or
	// page to redirect the client browser to when a url is blocked.
	BDS_Buffer key, value;
	BOOL success = true;

    // Get the first config entry.
    if ( success )
    {
	    success =  get_first_config_entry(key, value);
        if ( !success )
        {
    		// log "No entries in configuration section" to Event log
        }
    }

    // Check that the key is valid.
    if ( success )
    {
        if ( key != UBK_BLOCK_URL_ENTRY )
        {
            success = false;
			// log "Invalid entry in configuration section" to Event log
        }

    }

    // Check that the value is valid.
    if ( success )
    {
        if ( value.length() == 0 )
        {
            success = false;
			// log "Missing value in configuration section" to Event log
        }
        else
        {
            m_block_url = value;
        }
    }

    if ( success )
    {
        success = get_next_config_entry( key, value );
        if ( !success )
        {
		    // log "Missing entry in configuration section" to Event log
        }
    }

    // Check that the value is valid
    if ( success )
    {
        if ( value.length() == 0 )
        {
            success = false;
			// log "Missing value in configuration section" to Event log
        }
        else
        {
            m_block_message = value;
        }
    }

    // Check the key
    if ( success )
    {
	    if ( key == UBK_BLOCK_MESSAGE_ENTRY )
        {
            m_block_message = value;
        }
        else
        if ( key == UBK_REDIRECT_ENTRY )
        {
			m_block_message = "HTTP/1.0 301 Moved Permanently\r\n";
			m_block_message += "Location: ";
			m_block_message += value;
			m_block_message += "\r\n\r\n";
            m_block_message += "<a href=";
            m_block_message += value;
            m_block_message += ">Requested file has moved here</a>";
        }
        else
        {
            success = false;
			// log "Unexpected entry in configuration section" to Event log
        }
    }
	return success;
}


// This function blocks any url starting with the string specified in
// the configuration file. This url is blocked regardless of the host
// (host_ip_addr) that requested the file.
BOOL Simple_block::block_query(char* url, long host_ip_addr, BDS_Buffer& reason_text)
{
	BOOL block_url = FALSE;
	BDS_Buffer url_str = url;
	if(url_str(0, m_block_url.length() - 1) == m_block_url)
	{
		block_url = TRUE;
		reason_text = m_block_message;
	}
	return block_url;
}